/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlSystem.h"
#include "HvControlUnop.h"
#include "HvSignalVar.h"
#include "HvMath.h"
#include "HvSignalBiquad.h"
#include "HvControlCast.h"
#include "HvControlVar.h"
#include "HvControlIf.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_jdmA9FUl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_A8VbkTCO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_168S8mCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_BTbIqFw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_rthMRaJv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_S4j2hlVE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sx16xHFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hMn2uStN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_pTmMWROw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_geTIQDPU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_RbMEWqlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QV4nV9C8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HXGNwip7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NDPixAbL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WnDMpRn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6dLH8xFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9iBhzUUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zALoxOym_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Yee0B0I6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qt69S7GU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_J6g0UJmb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ADgrxaVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RgtfYsNv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bmuxD7ot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mv8grFLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GuVWOQvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PKmidUHO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7Sg7nWEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rb8CFy3f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ucbh0VjS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DJGNmAKE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tng9yCCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qKRDJJ17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_bHFS3DzC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_e6ebnWB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GzDgAnp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hNWSso0M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y7nMt5nR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QE7j4osw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hYZModYx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R3tI0NL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WwXvQWCu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HqNajfCt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_7u2kLyWc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UxpIki8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1o09Sl3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ul9q4giv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3w2ggab1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ad7NKOhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DZ5fJkYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eTPFGbEX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ptd7WS2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V14IIHo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9oeqDr1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aixrSF8k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_gpwGoKzW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eggk3yR1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UyaNQRB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k5Sp29DA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0OmNMh7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hQP2CGBC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n0x2RLYy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1UfOpIXy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a72SvWF8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lfFJML6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gbeAofTZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_aB9Qs7mF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Of5uvdMq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OZvDoZFC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_A21SOp3g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h21F7B3i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C7WrD63M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q0Hzq6dN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JlvRE9pL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YfCRPQF9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xICx9pXl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8Qoh9cft_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hjpMuCTo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_RVxSWYYT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CUcn2IEb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LMLllTOr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_kEeH992L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_g52rBLl9_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_XU8rIZZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dxtxzrHW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_EK4ZzRue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_oZse9ECt_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BBaVcrJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cGPdl36I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_RqmztFja_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YxAscSS0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7f7ghyC6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PQRetnKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fjQmTALC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ra2I9ZNS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dkArlce6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qjXJ0ZXJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xFYB2xKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DoCvvTtV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tAcYnHoE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_j6Ho33ct_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_11eFKYyH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_X1YDLwNc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i9xPbcZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EA9TH2JV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5NhFKrq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K9oR3cfc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3loIzBMF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FDj2r9pN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaLsXlRS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dGqQzZIp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mTeQWixS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mUXIzNzF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NcDRhYWr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wnzkJqqd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_S9ztWMGP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QUXpZT2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DoawhcMV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ysRHIvAQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_US8Zm81f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RmBe1NoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gEXhhLLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZWG3ZnPG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9VcyCyJw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_fe8nX5oe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JOf1p8lt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pjJCyGhe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XpqxPf5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sdY15pRn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0EgB2OrQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_jKvN6LD7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JB7BXbNr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_k126DJPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xzmE9vN7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hjRxQDkG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjN2A5jJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VxirrVEY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_moh6ecYP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_10l7gDFs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Ugk1lX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vXBtsh0X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_46cRf48E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zLOptZnq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SNDnNTQi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6YxYMdqq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3ZB1ITGT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nQvK0jw8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BbZS51ac_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vLIMXGeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VgBC2zEu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9EuBzLhP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TzwCceSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tDgSXrhI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BTVlo7ut_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qgHapuog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZKToY5TM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UYFGHQUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7sl1qZJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9x6sK0Ik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EqTlfeog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yPSs7Y9F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5sRgHkxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5xJfF3X2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z3QByPr1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_arnoHZbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_kOklj96P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_w0uRbMxF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HAF8cjMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ogKNYVOm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iBib8VLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2DImVkgM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y7EsJPsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5pqFuDpS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lpVCckYQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LuEzwqde_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_e8KlFrx6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tLe9Ouqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_d2Q5PqAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_F0DIbcLP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cHa64AhQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_a2vzF2hF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_TqVrgQZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_B0Xn0BYq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5EfbSNoD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NbxOdD6Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yYGDPcmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eVAObgiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OlRw5T4T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XZvOxiWK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HU4rgvVd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PA5vXQGW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GTzkABYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ek7kOCWh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_j7EwrwNe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mBFnfWKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SyoQ0pEA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EkCJQz5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m5lHTrmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MwCwRldV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_94ZyV4bI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eYmSN0og_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EbmzYGup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QvU4GoVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QdFBOks4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bW4pViDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AAclmSix_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9UuUXMk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_KCrFY8CD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_BWjEb94f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XisRQCal_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KeymLbuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zIM2ETbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xEIeq0XB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GODhRRs2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_LsBeOnGm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ytpzIsfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cYciMcGq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Stuz4SRZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QSaNiFcS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_85nQJyPR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vRG4lySq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_db8X8vK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JiC7pFRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n5MNrehs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AZiMkBmd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L96rODy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4nj8CnaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nglyN17m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pQN1YH7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LIGUR9fG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MR3KrgGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5oZrCqya_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7pi6vq9V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ixq7xj8e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2DaJTWSl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nToAaLAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4fiaUnoz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_MiH7EISr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_En71qctb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NCFzbaG3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N35Q3Qcf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lJfHAGio_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yJBfmgWO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vQUVa5hc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jA9o4ahq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9VhRg6bP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5kAl2jIv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y8owc6Qj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_77PAC1JB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FTPkBO3z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qcg8pryV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E9qcEHGQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vnv8SGDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9G53COYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5AoOYRUB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GRnefHuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_q7eOb3UF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M81sI5dz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9VQmZBwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jqIwqPVv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EPV8vkoY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZNgsskTv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_06mzYxGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z3ThGhEh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MxHcE190_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_604Q60Kq_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_PIo28quH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2mY3uXHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OWSs9ODG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3nVE2R10_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_girpIGHq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_F1u7H5jR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0IawjZfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OIMmzpMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_21eCGYpj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V9Awlg9C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_m5x9Y3gq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yg9kd1NI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Htn6NBZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qGZbKE8z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HcI89s7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_79GEc8zL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cf2aV0Bh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o8BrTST3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7KBSMvJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dWb2tPIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vEaWEH5U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xZG20ocI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mSwOesLy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8kYGmWfg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pkJcfOFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FlF96X0q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7T5w2nk9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_99MOijmF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_twjGqtWk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5i8cCgJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HJeIvwna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pDRDu1Zq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pROw1D1z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XFVsjC8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UdGW55Ol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3mtxXpc6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Pg50ZmOe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cpj77hK4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_6A9iE4w0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GGwuaAvD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HFY35nrd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JA2Hmoab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p0MstwEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wTA3gpPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AqFMA4ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7s4DyotY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XRPLeorF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Wu56VW15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_35VBTYXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YMeeuotE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n6FbCfgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_xRJM3Rc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_73fzpBlx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_R6TwdKWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uG0nSF87_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6VJCGxfl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EUqTOdh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7feZPh3w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QXcm8ycC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RU3fKISd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_52w3xTca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_9lsWEuX8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C7CBWa1p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SZeP9FRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GTAvQK4I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xAKSb3ol_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XKLIpdWY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hi6MkPa1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fxBUP3RG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lXaaePtF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rPZRJ6QH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_0Jkf7nCR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ceZII5eP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MjOahGHD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_g4H0SfHm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RcgX1ahg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2ZFD5WPc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Et4DBtUi_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_xl44DChN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rV8QODXN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_hskLmkGJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_o21fz5z7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9W363Flq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_q4QL9SrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_j00LPDrz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1PUHQ30n_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_BFSuPpTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_eFySdU4s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_fHa3HbkL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nB6NErAL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BP4PbJKA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ULhBvMiE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AfhWCImw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lkce1zhm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CHlf9OiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_DheonKHA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hKnVeQMc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2I5y6WNp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tXfCrbkK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NyedcQ9w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h3WvPKMl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mKvVwxhB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_rQ9iDyXC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nbAmhFCG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SfD3Ovai_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3wqL1akq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GsmVHPiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cQlHC4jQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LZgW27sQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_6AINDqTD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hSX2Hqc9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NEsQ0UOR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oMo5D8Wr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FP16Y05L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zyp6Gjfv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q84Xe37I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SKa5t84C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QYnJSciL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NnfxmoLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lJsYf6rP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_WM6Ixemo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Iet03Ivm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_fzqqTsmQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_J1TsLNV9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_1cGwpibB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JocsqKAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h4Jzos0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5cbvcFuw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_StxNVpFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7oRONXJk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_phfOFc20_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RuddYvHa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_smSiLvBU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DAW8G9Ql_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VhifYRTj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xnWVfIuX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hyCEEdFF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zAgJhkE8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yDqCr4EY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ADR5a8kz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5j6i0UgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hEHPoPg1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wdPNCwxt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_K54uAz8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Ovjy49ee_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XSc8sIIy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dP8cOF95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UKxJDaPI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IGDI6GJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UUUe9Oue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bzrVxrRX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_AO7JcE6h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_68rYn1yd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xqDUpbtU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yjYZJJiW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0kiPOs4Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LM8XLX01_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xAdA3wmB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ngk2Uz92_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Zb1EBZwq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_872W5if6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XSthjKth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fm8Bc8N2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O2MaZBj3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_njznbR3B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vjCalB2S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K9eCErwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HhbMlXkH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1sM2qmsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TDp118a8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_OvRqKk8G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_a4KAFqoa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rjXTWBEc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gDLt5Mmt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aErMVIth_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Lo76tSoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_LNteIlvs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CQ40ocua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V39Ip7WA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mdbnPy15_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6bF1RLVJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iPXEEbcp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_u8ZT17w6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eeasFlIf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O71JH1n4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_M5mwRioV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OfrvyB0c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tD3peYXR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W8ob96az_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mK9JJCeT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CNmLnWmn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JLt31ruu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VODgcnNl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5S3qiMJs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HGnsaEYa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I6tERfmO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Si5MWy5z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3vocsqab_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3hX01NIF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_FCOs9qsP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SSCZuFNd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ANI3HLxK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_1CVGD2ES_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_29xMvMYt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRlhR392_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9m2FTNxn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BqlReucw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vQdIw3Q3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrhng7Oz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_lwUZRIVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9qYjAVrf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cWPdGYRU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oD5uXUqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0JmMIthM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JibSxRcX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bJ3X1oMi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2qcvY6iQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kAOi8ecQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8AvsvqxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2Idud7PB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5Jv3EC3U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mkFoDpQS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kcWF8nDj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_srOtpJtD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_17Esko6k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_McXLazgz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sh8W71nJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_7zHJLvZm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yEi1Z692_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lT7vg5pk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iPoYx0WN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UEPOgEKG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uqiWMkr2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7VtYxc3I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_zxoWe7R1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cHCfEG7H_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mzIsT6Xe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lVM54YI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1SAzhrmC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_M2zuOjOQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wMWIENLt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPnbjdet_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_W9BVg9c0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_j9jlasho_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nlTbFrXF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z6sdrS8K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G1GF9AcI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_I6gsx2mI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PfOzMUsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aoChITow_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ihUJgCxq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IACMoBAW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Dj0U0OQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7HpD6zfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OwaoWtvF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PxKZrkv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZh88TWS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TCEw7CPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nokqIgtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6HcG0iVf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DJYcNqPb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2ie0wll8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_YG8z0mnA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_NHKeRiMz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_i1kldreE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aLKsMRlq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bZBocYwb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0z1cpKoC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ok1HEJgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lOpgQnCS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_iqXjszDb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1ewOXt2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KRy7bXjA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8eZ8dCwQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nuckqBMo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P3osyH7A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x4tSoyZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_C5MBsvPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P4tmxdYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_O0KjohsL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_upDEUW33_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p4S6cWgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PRE6QtEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CdfJq6wQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_0ygi1N7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FWgIijfx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_UHqiu6CZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lT1IuJrW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_f9qg56YQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_33sEnqTa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_k9TyNS5C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_e8mPZ16X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HUt1RYK2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CAMma95i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_EGRTDO8x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YE2MqUs5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xBbUlcUK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JJjxXPcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_YOzNjm9l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2g4oLSr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_FAwz3Gku_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uxTmbK4q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tR379nMM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_jq0m9rwu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uirGeezY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_DfpEXY2n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_gh6Lgw7W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kyHn4l1X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T5mOEu8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_A0HwPEwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_kktaTeQL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_8IlsaEAR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uDBTjqZ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R3scQNGK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yvilhnDy_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_c0D79il9;
  SignalLine sLine_iJHKU8Ge;
  SignalLine sLine_TXpf2yq6;
  SignalLine sLine_i0ebYvao;
  SignalLine sLine_vEq87I65;
  SignalBiquad sBiquad_s_dCIqLV6t;
  SignalLine sLine_bgJorfWO;
  SignalLine sLine_heJqhLPw;
  SignalLine sLine_SInEiuYb;
  SignalLine sLine_CfufUUbm;
  SignalBiquad sBiquad_s_LlPTWZNj;
  SignalLine sLine_9rwB7HSw;
  SignalLine sLine_KyGvW0jx;
  SignalLine sLine_RbdekJqV;
  SignalLine sLine_rLKg8pux;
  SignalLine sLine_sbhNeIwL;
  SignalBiquad sBiquad_s_bWd3IxP3;
  SignalLine sLine_HXyEHTNa;
  SignalLine sLine_SUww0ejw;
  SignalLine sLine_bbHbNLmD;
  SignalLine sLine_ui27WL2g;
  SignalLine sLine_bviSj19E;
  SignalBiquad sBiquad_s_yVYZ8Gf9;
  SignalLine sLine_2495c0hI;
  SignalLine sLine_NDMk3al6;
  SignalLine sLine_rJmf5G3O;
  SignalLine sLine_33mfSqbe;
  SignalBiquad sBiquad_s_0E9n6DHc;
  SignalLine sLine_watCYEHl;
  SignalLine sLine_th5WwSIZ;
  SignalLine sLine_2aRaU7th;
  SignalLine sLine_Ff3QFqiy;
  SignalLine sLine_tTPO4ZQO;
  SignalBiquad sBiquad_s_klsJqEK6;
  ControlVar cVar_jdmA9FUl;
  ControlVar cVar_A8VbkTCO;
  ControlVar cVar_168S8mCl;
  ControlVar cVar_BTbIqFw4;
  ControlSlice cSlice_S4j2hlVE;
  ControlVar cVar_sx16xHFr;
  ControlVar cVar_pTmMWROw;
  ControlIf cIf_geTIQDPU;
  ControlIf cIf_RbMEWqlY;
  ControlBinop cBinop_HXGNwip7;
  ControlBinop cBinop_NDPixAbL;
  ControlBinop cBinop_9iBhzUUp;
  ControlBinop cBinop_zALoxOym;
  ControlBinop cBinop_Qt69S7GU;
  ControlIf cIf_J6g0UJmb;
  ControlBinop cBinop_ADgrxaVO;
  ControlBinop cBinop_RgtfYsNv;
  ControlBinop cBinop_Mv8grFLA;
  ControlBinop cBinop_GuVWOQvZ;
  ControlBinop cBinop_PKmidUHO;
  ControlVar cVar_Tng9yCCf;
  ControlIf cIf_qKRDJJ17;
  ControlIf cIf_bHFS3DzC;
  ControlBinop cBinop_GzDgAnp7;
  ControlBinop cBinop_hNWSso0M;
  ControlBinop cBinop_hYZModYx;
  ControlBinop cBinop_R3tI0NL5;
  ControlBinop cBinop_HqNajfCt;
  ControlIf cIf_7u2kLyWc;
  ControlBinop cBinop_UxpIki8N;
  ControlBinop cBinop_1o09Sl3s;
  ControlBinop cBinop_3w2ggab1;
  ControlBinop cBinop_Ad7NKOhP;
  ControlBinop cBinop_DZ5fJkYO;
  ControlVar cVar_aixrSF8k;
  ControlIf cIf_gpwGoKzW;
  ControlIf cIf_eggk3yR1;
  ControlBinop cBinop_k5Sp29DA;
  ControlBinop cBinop_0OmNMh7l;
  ControlBinop cBinop_1UfOpIXy;
  ControlBinop cBinop_a72SvWF8;
  ControlBinop cBinop_gbeAofTZ;
  ControlIf cIf_aB9Qs7mF;
  ControlBinop cBinop_Of5uvdMq;
  ControlBinop cBinop_OZvDoZFC;
  ControlBinop cBinop_h21F7B3i;
  ControlBinop cBinop_C7WrD63M;
  ControlBinop cBinop_q0Hzq6dN;
  ControlIf cIf_hjpMuCTo;
  ControlSlice cSlice_CUcn2IEb;
  ControlVar cVar_LMLllTOr;
  ControlSlice cSlice_XU8rIZZb;
  ControlVar cVar_dxtxzrHW;
  ControlSlice cSlice_BBaVcrJ3;
  ControlVar cVar_cGPdl36I;
  ControlSlice cSlice_7f7ghyC6;
  ControlVar cVar_PQRetnKZ;
  ControlBinop cBinop_i9xPbcZl;
  ControlBinop cBinop_u5NhFKrq;
  ControlBinop cBinop_K9oR3cfc;
  ControlBinop cBinop_BaLsXlRS;
  ControlBinop cBinop_dGqQzZIp;
  ControlBinop cBinop_mTeQWixS;
  ControlBinop cBinop_mUXIzNzF;
  ControlBinop cBinop_NcDRhYWr;
  ControlVar cVar_wnzkJqqd;
  ControlBinop cBinop_S9ztWMGP;
  ControlBinop cBinop_QUXpZT2r;
  ControlBinop cBinop_DoawhcMV;
  ControlBinop cBinop_ysRHIvAQ;
  ControlBinop cBinop_US8Zm81f;
  ControlBinop cBinop_RmBe1NoU;
  ControlBinop cBinop_gEXhhLLH;
  ControlBinop cBinop_9VcyCyJw;
  ControlVar cVar_fe8nX5oe;
  ControlVar cVar_JOf1p8lt;
  ControlBinop cBinop_k126DJPb;
  ControlBinop cBinop_xzmE9vN7;
  ControlBinop cBinop_hjRxQDkG;
  ControlBinop cBinop_VxirrVEY;
  ControlBinop cBinop_moh6ecYP;
  ControlBinop cBinop_10l7gDFs;
  ControlBinop cBinop_1Ugk1lX4;
  ControlBinop cBinop_vXBtsh0X;
  ControlBinop cBinop_46cRf48E;
  ControlBinop cBinop_yPSs7Y9F;
  ControlBinop cBinop_5xJfF3X2;
  ControlBinop cBinop_z3QByPr1;
  ControlBinop cBinop_w0uRbMxF;
  ControlBinop cBinop_HAF8cjMs;
  ControlBinop cBinop_ogKNYVOm;
  ControlBinop cBinop_iBib8VLj;
  ControlBinop cBinop_2DImVkgM;
  ControlBinop cBinop_y7EsJPsS;
  ControlBinop cBinop_5pqFuDpS;
  ControlBinop cBinop_LuEzwqde;
  ControlVar cVar_e8KlFrx6;
  ControlVar cVar_tLe9Ouqn;
  ControlVar cVar_d2Q5PqAI;
  ControlBinop cBinop_NbxOdD6Q;
  ControlBinop cBinop_yYGDPcmj;
  ControlBinop cBinop_eVAObgiq;
  ControlBinop cBinop_XZvOxiWK;
  ControlBinop cBinop_HU4rgvVd;
  ControlBinop cBinop_PA5vXQGW;
  ControlBinop cBinop_GTzkABYt;
  ControlBinop cBinop_ek7kOCWh;
  ControlBinop cBinop_KeymLbuw;
  ControlBinop cBinop_xEIeq0XB;
  ControlBinop cBinop_GODhRRs2;
  ControlBinop cBinop_cYciMcGq;
  ControlBinop cBinop_Stuz4SRZ;
  ControlBinop cBinop_QSaNiFcS;
  ControlBinop cBinop_85nQJyPR;
  ControlBinop cBinop_vRG4lySq;
  ControlBinop cBinop_JiC7pFRo;
  ControlBinop cBinop_AZiMkBmd;
  ControlBinop cBinop_L96rODy9;
  ControlBinop cBinop_nglyN17m;
  ControlBinop cBinop_pQN1YH7L;
  ControlBinop cBinop_LIGUR9fG;
  ControlBinop cBinop_5oZrCqya;
  ControlVar cVar_7pi6vq9V;
  ControlVar cVar_ixq7xj8e;
  ControlVar cVar_2DaJTWSl;
  ControlBinop cBinop_lJfHAGio;
  ControlBinop cBinop_yJBfmgWO;
  ControlBinop cBinop_vQUVa5hc;
  ControlBinop cBinop_9VhRg6bP;
  ControlBinop cBinop_5kAl2jIv;
  ControlBinop cBinop_y8owc6Qj;
  ControlBinop cBinop_77PAC1JB;
  ControlBinop cBinop_FTPkBO3z;
  ControlBinop cBinop_qcg8pryV;
  ControlBinop cBinop_ZNgsskTv;
  ControlBinop cBinop_z3ThGhEh;
  ControlBinop cBinop_MxHcE190;
  SignalVarf sVarf_RJHIgJ3l;
  SignalVarf sVarf_iwPjuLCM;
  SignalVarf sVarf_fDO0pHfw;
  ControlSlice cSlice_PIo28quH;
  ControlVar cVar_2mY3uXHe;
  ControlVar cVar_3nVE2R10;
  ControlIf cIf_girpIGHq;
  ControlIf cIf_F1u7H5jR;
  ControlBinop cBinop_OIMmzpMm;
  ControlBinop cBinop_21eCGYpj;
  ControlBinop cBinop_Yg9kd1NI;
  ControlBinop cBinop_2Htn6NBZ;
  ControlBinop cBinop_HcI89s7l;
  ControlIf cIf_79GEc8zL;
  ControlBinop cBinop_cf2aV0Bh;
  ControlBinop cBinop_o8BrTST3;
  ControlBinop cBinop_dWb2tPIQ;
  ControlBinop cBinop_vEaWEH5U;
  ControlBinop cBinop_xZG20ocI;
  ControlVar cVar_7T5w2nk9;
  ControlIf cIf_99MOijmF;
  ControlIf cIf_twjGqtWk;
  ControlBinop cBinop_HJeIvwna;
  ControlBinop cBinop_pDRDu1Zq;
  ControlBinop cBinop_UdGW55Ol;
  ControlBinop cBinop_3mtxXpc6;
  ControlBinop cBinop_Cpj77hK4;
  ControlIf cIf_6A9iE4w0;
  ControlBinop cBinop_GGwuaAvD;
  ControlBinop cBinop_HFY35nrd;
  ControlBinop cBinop_p0MstwEv;
  ControlBinop cBinop_wTA3gpPS;
  ControlBinop cBinop_AqFMA4ra;
  ControlVar cVar_YMeeuotE;
  ControlIf cIf_n6FbCfgY;
  ControlIf cIf_xRJM3Rc1;
  ControlBinop cBinop_R6TwdKWB;
  ControlBinop cBinop_uG0nSF87;
  ControlBinop cBinop_7feZPh3w;
  ControlBinop cBinop_QXcm8ycC;
  ControlBinop cBinop_52w3xTca;
  ControlIf cIf_9lsWEuX8;
  ControlBinop cBinop_C7CBWa1p;
  ControlBinop cBinop_SZeP9FRo;
  ControlBinop cBinop_xAKSb3ol;
  ControlBinop cBinop_XKLIpdWY;
  ControlBinop cBinop_Hi6MkPa1;
  ControlIf cIf_ceZII5eP;
  ControlSlice cSlice_g4H0SfHm;
  ControlVar cVar_RcgX1ahg;
  ControlSlice cSlice_xl44DChN;
  ControlVar cVar_rV8QODXN;
  ControlSlice cSlice_9W363Flq;
  ControlVar cVar_q4QL9SrK;
  ControlSlice cSlice_BFSuPpTH;
  ControlVar cVar_eFySdU4s;
  ControlBinop cBinop_tXfCrbkK;
  ControlBinop cBinop_h3WvPKMl;
  ControlBinop cBinop_mKvVwxhB;
  ControlBinop cBinop_SfD3Ovai;
  ControlBinop cBinop_3wqL1akq;
  ControlBinop cBinop_GsmVHPiq;
  ControlBinop cBinop_cQlHC4jQ;
  ControlBinop cBinop_LZgW27sQ;
  ControlVar cVar_6AINDqTD;
  ControlBinop cBinop_hSX2Hqc9;
  ControlBinop cBinop_NEsQ0UOR;
  ControlBinop cBinop_oMo5D8Wr;
  ControlBinop cBinop_FP16Y05L;
  ControlBinop cBinop_Zyp6Gjfv;
  ControlBinop cBinop_q84Xe37I;
  ControlBinop cBinop_SKa5t84C;
  ControlBinop cBinop_NnfxmoLr;
  ControlVar cVar_lJsYf6rP;
  ControlVar cVar_WM6Ixemo;
  ControlBinop cBinop_5cbvcFuw;
  ControlBinop cBinop_StxNVpFr;
  ControlBinop cBinop_7oRONXJk;
  ControlBinop cBinop_RuddYvHa;
  ControlBinop cBinop_smSiLvBU;
  ControlBinop cBinop_DAW8G9Ql;
  ControlBinop cBinop_VhifYRTj;
  ControlBinop cBinop_xnWVfIuX;
  ControlBinop cBinop_hyCEEdFF;
  ControlBinop cBinop_0kiPOs4Y;
  ControlBinop cBinop_xAdA3wmB;
  ControlBinop cBinop_ngk2Uz92;
  ControlBinop cBinop_XSthjKth;
  ControlBinop cBinop_Fm8Bc8N2;
  ControlBinop cBinop_O2MaZBj3;
  ControlBinop cBinop_njznbR3B;
  ControlBinop cBinop_vjCalB2S;
  ControlBinop cBinop_K9eCErwI;
  ControlBinop cBinop_HhbMlXkH;
  ControlBinop cBinop_TDp118a8;
  ControlVar cVar_OvRqKk8G;
  ControlVar cVar_a4KAFqoa;
  ControlVar cVar_rjXTWBEc;
  ControlBinop cBinop_mdbnPy15;
  ControlBinop cBinop_6bF1RLVJ;
  ControlBinop cBinop_iPXEEbcp;
  ControlBinop cBinop_eeasFlIf;
  ControlBinop cBinop_O71JH1n4;
  ControlBinop cBinop_M5mwRioV;
  ControlBinop cBinop_OfrvyB0c;
  ControlBinop cBinop_tD3peYXR;
  ControlBinop cBinop_9m2FTNxn;
  ControlBinop cBinop_vQdIw3Q3;
  ControlBinop cBinop_wrhng7Oz;
  ControlBinop cBinop_cWPdGYRU;
  ControlBinop cBinop_oD5uXUqF;
  ControlBinop cBinop_0JmMIthM;
  ControlBinop cBinop_JibSxRcX;
  ControlBinop cBinop_bJ3X1oMi;
  ControlBinop cBinop_kAOi8ecQ;
  ControlBinop cBinop_2Idud7PB;
  ControlBinop cBinop_5Jv3EC3U;
  ControlBinop cBinop_kcWF8nDj;
  ControlBinop cBinop_srOtpJtD;
  ControlBinop cBinop_17Esko6k;
  ControlBinop cBinop_sh8W71nJ;
  ControlVar cVar_7zHJLvZm;
  ControlVar cVar_yEi1Z692;
  ControlVar cVar_lT7vg5pk;
  ControlBinop cBinop_mzIsT6Xe;
  ControlBinop cBinop_lVM54YI0;
  ControlBinop cBinop_1SAzhrmC;
  ControlBinop cBinop_wMWIENLt;
  ControlBinop cBinop_pPnbjdet;
  ControlBinop cBinop_W9BVg9c0;
  ControlBinop cBinop_j9jlasho;
  ControlBinop cBinop_nlTbFrXF;
  ControlBinop cBinop_z6sdrS8K;
  ControlBinop cBinop_qZh88TWS;
  ControlBinop cBinop_nokqIgtY;
  ControlBinop cBinop_6HcG0iVf;
  SignalVarf sVarf_W1UeyKoj;
  SignalVarf sVarf_RLOhNWu9;
  SignalVarf sVarf_MBn5APwX;
  SignalVarf sVarf_fUI44oSa;
  SignalVarf sVarf_NTlQNedF;
  SignalVarf sVarf_5XNC185k;
  SignalVarf sVarf_hOV00G0m;
  SignalVarf sVarf_0vwl8n7w;
  SignalVarf sVarf_Ua15118s;
  ControlVar cVar_DJYcNqPb;
  ControlVar cVar_2ie0wll8;
  ControlBinop cBinop_0z1cpKoC;
  ControlBinop cBinop_ok1HEJgH;
  ControlBinop cBinop_lOpgQnCS;
  ControlBinop cBinop_1ewOXt2h;
  ControlBinop cBinop_KRy7bXjA;
  ControlBinop cBinop_8eZ8dCwQ;
  ControlBinop cBinop_nuckqBMo;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
