/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_c0D79il9);
  numBytes += sLine_init(&sLine_iJHKU8Ge);
  numBytes += sLine_init(&sLine_TXpf2yq6);
  numBytes += sLine_init(&sLine_i0ebYvao);
  numBytes += sLine_init(&sLine_vEq87I65);
  numBytes += sBiquad_init(&sBiquad_s_dCIqLV6t);
  numBytes += sLine_init(&sLine_bgJorfWO);
  numBytes += sLine_init(&sLine_heJqhLPw);
  numBytes += sLine_init(&sLine_SInEiuYb);
  numBytes += sLine_init(&sLine_CfufUUbm);
  numBytes += sBiquad_init(&sBiquad_s_LlPTWZNj);
  numBytes += sLine_init(&sLine_9rwB7HSw);
  numBytes += sLine_init(&sLine_KyGvW0jx);
  numBytes += sLine_init(&sLine_RbdekJqV);
  numBytes += sLine_init(&sLine_rLKg8pux);
  numBytes += sLine_init(&sLine_sbhNeIwL);
  numBytes += sBiquad_init(&sBiquad_s_bWd3IxP3);
  numBytes += sLine_init(&sLine_HXyEHTNa);
  numBytes += sLine_init(&sLine_SUww0ejw);
  numBytes += sLine_init(&sLine_bbHbNLmD);
  numBytes += sLine_init(&sLine_ui27WL2g);
  numBytes += sLine_init(&sLine_bviSj19E);
  numBytes += sBiquad_init(&sBiquad_s_yVYZ8Gf9);
  numBytes += sLine_init(&sLine_2495c0hI);
  numBytes += sLine_init(&sLine_NDMk3al6);
  numBytes += sLine_init(&sLine_rJmf5G3O);
  numBytes += sLine_init(&sLine_33mfSqbe);
  numBytes += sBiquad_init(&sBiquad_s_0E9n6DHc);
  numBytes += sLine_init(&sLine_watCYEHl);
  numBytes += sLine_init(&sLine_th5WwSIZ);
  numBytes += sLine_init(&sLine_2aRaU7th);
  numBytes += sLine_init(&sLine_Ff3QFqiy);
  numBytes += sLine_init(&sLine_tTPO4ZQO);
  numBytes += sBiquad_init(&sBiquad_s_klsJqEK6);
  numBytes += cVar_init_f(&cVar_jdmA9FUl, 0.0f);
  numBytes += cVar_init_f(&cVar_A8VbkTCO, 0.0f);
  numBytes += cVar_init_f(&cVar_168S8mCl, 0.0f);
  numBytes += cVar_init_f(&cVar_BTbIqFw4, 0.0f);
  numBytes += cSlice_init(&cSlice_S4j2hlVE, 1, -1);
  numBytes += cVar_init_f(&cVar_sx16xHFr, 1337.0f);
  numBytes += cVar_init_f(&cVar_pTmMWROw, 0.0f);
  numBytes += cIf_init(&cIf_geTIQDPU, false);
  numBytes += cIf_init(&cIf_RbMEWqlY, false);
  numBytes += cBinop_init(&cBinop_HXGNwip7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_J6g0UJmb, false);
  numBytes += cBinop_init(&cBinop_Mv8grFLA, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_GuVWOQvZ, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_PKmidUHO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Tng9yCCf, 0.0f);
  numBytes += cIf_init(&cIf_qKRDJJ17, false);
  numBytes += cIf_init(&cIf_bHFS3DzC, false);
  numBytes += cBinop_init(&cBinop_GzDgAnp7, 0.0f); // __pow
  numBytes += cIf_init(&cIf_7u2kLyWc, false);
  numBytes += cBinop_init(&cBinop_3w2ggab1, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Ad7NKOhP, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_DZ5fJkYO, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_aixrSF8k, 0.0f);
  numBytes += cIf_init(&cIf_gpwGoKzW, false);
  numBytes += cIf_init(&cIf_eggk3yR1, false);
  numBytes += cBinop_init(&cBinop_k5Sp29DA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_aB9Qs7mF, false);
  numBytes += cBinop_init(&cBinop_h21F7B3i, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_C7WrD63M, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_q0Hzq6dN, -15.0f); // __eq
  numBytes += cIf_init(&cIf_hjpMuCTo, false);
  numBytes += cSlice_init(&cSlice_CUcn2IEb, 1, -1);
  numBytes += cVar_init_f(&cVar_LMLllTOr, 0.0f);
  numBytes += cSlice_init(&cSlice_XU8rIZZb, 1, -1);
  numBytes += cVar_init_f(&cVar_dxtxzrHW, 0.0f);
  numBytes += cSlice_init(&cSlice_BBaVcrJ3, 1, -1);
  numBytes += cVar_init_f(&cVar_cGPdl36I, 0.0f);
  numBytes += cSlice_init(&cSlice_7f7ghyC6, 1, -1);
  numBytes += cVar_init_f(&cVar_PQRetnKZ, 0.313f);
  numBytes += cBinop_init(&cBinop_u5NhFKrq, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_K9oR3cfc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_wnzkJqqd, 0.0f);
  numBytes += cVar_init_f(&cVar_fe8nX5oe, 1337.0f);
  numBytes += cVar_init_f(&cVar_JOf1p8lt, 0.3f);
  numBytes += cBinop_init(&cBinop_xzmE9vN7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_moh6ecYP, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_10l7gDFs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_1Ugk1lX4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vXBtsh0X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_46cRf48E, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5xJfF3X2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_z3QByPr1, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_e8KlFrx6, 0.0f);
  numBytes += cVar_init_f(&cVar_tLe9Ouqn, 1337.0f);
  numBytes += cVar_init_f(&cVar_d2Q5PqAI, 0.313f);
  numBytes += cBinop_init(&cBinop_yYGDPcmj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HU4rgvVd, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PA5vXQGW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_GTzkABYt, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ek7kOCWh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xEIeq0XB, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_GODhRRs2, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7pi6vq9V, 0.0f);
  numBytes += cVar_init_f(&cVar_ixq7xj8e, 1037.0f);
  numBytes += cVar_init_f(&cVar_2DaJTWSl, 0.4f);
  numBytes += cBinop_init(&cBinop_yJBfmgWO, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5kAl2jIv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_y8owc6Qj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_77PAC1JB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FTPkBO3z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qcg8pryV, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_RJHIgJ3l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iwPjuLCM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fDO0pHfw, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_PIo28quH, 1, -1);
  numBytes += cVar_init_f(&cVar_2mY3uXHe, 1337.0f);
  numBytes += cVar_init_f(&cVar_3nVE2R10, 0.0f);
  numBytes += cIf_init(&cIf_girpIGHq, false);
  numBytes += cIf_init(&cIf_F1u7H5jR, false);
  numBytes += cBinop_init(&cBinop_OIMmzpMm, 0.0f); // __pow
  numBytes += cIf_init(&cIf_79GEc8zL, false);
  numBytes += cBinop_init(&cBinop_dWb2tPIQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_vEaWEH5U, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_xZG20ocI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_7T5w2nk9, 0.0f);
  numBytes += cIf_init(&cIf_99MOijmF, false);
  numBytes += cIf_init(&cIf_twjGqtWk, false);
  numBytes += cBinop_init(&cBinop_HJeIvwna, 0.0f); // __pow
  numBytes += cIf_init(&cIf_6A9iE4w0, false);
  numBytes += cBinop_init(&cBinop_p0MstwEv, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_wTA3gpPS, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_AqFMA4ra, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_YMeeuotE, 0.0f);
  numBytes += cIf_init(&cIf_n6FbCfgY, false);
  numBytes += cIf_init(&cIf_xRJM3Rc1, false);
  numBytes += cBinop_init(&cBinop_R6TwdKWB, 0.0f); // __pow
  numBytes += cIf_init(&cIf_9lsWEuX8, false);
  numBytes += cBinop_init(&cBinop_xAKSb3ol, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_XKLIpdWY, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Hi6MkPa1, -15.0f); // __eq
  numBytes += cIf_init(&cIf_ceZII5eP, false);
  numBytes += cSlice_init(&cSlice_g4H0SfHm, 1, -1);
  numBytes += cVar_init_f(&cVar_RcgX1ahg, 0.0f);
  numBytes += cSlice_init(&cSlice_xl44DChN, 1, -1);
  numBytes += cVar_init_f(&cVar_rV8QODXN, 0.0f);
  numBytes += cSlice_init(&cSlice_9W363Flq, 1, -1);
  numBytes += cVar_init_f(&cVar_q4QL9SrK, 0.0f);
  numBytes += cSlice_init(&cSlice_BFSuPpTH, 1, -1);
  numBytes += cVar_init_f(&cVar_eFySdU4s, 0.313f);
  numBytes += cBinop_init(&cBinop_h3WvPKMl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_mKvVwxhB, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_6AINDqTD, 0.0f);
  numBytes += cVar_init_f(&cVar_lJsYf6rP, 1337.0f);
  numBytes += cVar_init_f(&cVar_WM6Ixemo, 0.3f);
  numBytes += cBinop_init(&cBinop_StxNVpFr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_smSiLvBU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DAW8G9Ql, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VhifYRTj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xnWVfIuX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_hyCEEdFF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xAdA3wmB, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ngk2Uz92, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_OvRqKk8G, 0.0f);
  numBytes += cVar_init_f(&cVar_a4KAFqoa, 1337.0f);
  numBytes += cVar_init_f(&cVar_rjXTWBEc, 0.313f);
  numBytes += cBinop_init(&cBinop_6bF1RLVJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_O71JH1n4, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_M5mwRioV, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_OfrvyB0c, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_tD3peYXR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_vQdIw3Q3, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_wrhng7Oz, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_7zHJLvZm, 0.0f);
  numBytes += cVar_init_f(&cVar_yEi1Z692, 1037.0f);
  numBytes += cVar_init_f(&cVar_lT7vg5pk, 0.4f);
  numBytes += cBinop_init(&cBinop_lVM54YI0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pPnbjdet, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W9BVg9c0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_j9jlasho, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_nlTbFrXF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_z6sdrS8K, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_W1UeyKoj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RLOhNWu9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MBn5APwX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fUI44oSa, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_NTlQNedF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5XNC185k, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hOV00G0m, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0vwl8n7w, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Ua15118s, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_DJYcNqPb, 5705.6f);
  numBytes += cVar_init_f(&cVar_2ie0wll8, 313.3f);
  numBytes += cBinop_init(&cBinop_0z1cpKoC, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_ok1HEJgH, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_lOpgQnCS, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PRE6QtEO_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0ygi1N7J_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CdfJq6wQ_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yvilhnDy_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lT1IuJrW_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_f9qg56YQ_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FWgIijfx_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UHqiu6CZ_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_33sEnqTa_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CAMma95i_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HUt1RYK2_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_e8mPZ16X_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xBbUlcUK_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YE2MqUs5_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EGRTDO8x_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2g4oLSr0_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YOzNjm9l_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JJjxXPcQ_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tR379nMM_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jq0m9rwu_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FAwz3Gku_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uxTmbK4q_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uirGeezY_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kyHn4l1X_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gh6Lgw7W_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_DfpEXY2n_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_kktaTeQL_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A0HwPEwY_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T5mOEu8u_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R3scQNGK_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uDBTjqZ3_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_8IlsaEAR_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_k9TyNS5C_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_jdmA9FUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P3osyH7A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_A8VbkTCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x4tSoyZp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_168S8mCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_C5MBsvPP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_BTbIqFw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_P4tmxdYd_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i1kldreE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aLKsMRlq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bZBocYwb_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_rthMRaJv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_S4j2hlVE, 0, m, &cSlice_S4j2hlVE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_oZse9ECt_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_S4j2hlVE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hMn2uStN_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hMn2uStN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_sx16xHFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hMn2uStN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hMn2uStN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FWgIijfx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_pTmMWROw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ADgrxaVO_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_geTIQDPU, 0, m, &cIf_geTIQDPU_sendMessage);
}

void Heavy_WSTD_EQ::cIf_geTIQDPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_RgtfYsNv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_RbMEWqlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Yee0B0I6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_zALoxOym_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_QV4nV9C8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HXGNwip7, HV_BINOP_POW, 0, m, &cBinop_HXGNwip7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HXGNwip7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J6g0UJmb, 0, m, &cIf_J6g0UJmb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NDPixAbL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Qt69S7GU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_WnDMpRn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_9iBhzUUp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6dLH8xFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RbMEWqlY, 0, m, &cIf_RbMEWqlY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9iBhzUUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RbMEWqlY, 1, m, &cIf_RbMEWqlY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zALoxOym_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_NDPixAbL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Yee0B0I6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_J6g0UJmb, 0, m, &cIf_J6g0UJmb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qt69S7GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HXGNwip7, HV_BINOP_POW, 1, m, &cBinop_HXGNwip7_sendMessage);
  cMsg_QV4nV9C8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_J6g0UJmb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_RJHIgJ3l, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_ADgrxaVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_geTIQDPU, 1, m, &cIf_geTIQDPU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RgtfYsNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GuVWOQvZ, HV_BINOP_GREATER_THAN, 1, m, &cBinop_GuVWOQvZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PKmidUHO, HV_BINOP_EQ, 1, m, &cBinop_PKmidUHO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bmuxD7ot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mv8grFLA, HV_BINOP_ADD, 0, m, &cBinop_Mv8grFLA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Mv8grFLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WnDMpRn6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6dLH8xFu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GuVWOQvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J6g0UJmb, 1, m, &cIf_J6g0UJmb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PKmidUHO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Sg7nWEa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_7Sg7nWEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RJHIgJ3l, m);
}

void Heavy_WSTD_EQ::cCast_rb8CFy3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pTmMWROw, 0, m, &cVar_pTmMWROw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ucbh0VjS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bmuxD7ot_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_DJGNmAKE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mv8grFLA, HV_BINOP_ADD, 1, m, &cBinop_Mv8grFLA_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GuVWOQvZ, HV_BINOP_GREATER_THAN, 0, m, &cBinop_GuVWOQvZ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_PKmidUHO, HV_BINOP_EQ, 0, m, &cBinop_PKmidUHO_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Tng9yCCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UxpIki8N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qKRDJJ17, 0, m, &cIf_qKRDJJ17_sendMessage);
}

void Heavy_WSTD_EQ::cIf_qKRDJJ17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_1o09Sl3s_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_bHFS3DzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_WwXvQWCu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_R3tI0NL5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_e6ebnWB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzDgAnp7, HV_BINOP_POW, 0, m, &cBinop_GzDgAnp7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GzDgAnp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7u2kLyWc, 0, m, &cIf_7u2kLyWc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hNWSso0M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_HqNajfCt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Y7nMt5nR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hYZModYx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_QE7j4osw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bHFS3DzC, 0, m, &cIf_bHFS3DzC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hYZModYx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bHFS3DzC, 1, m, &cIf_bHFS3DzC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R3tI0NL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hNWSso0M_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WwXvQWCu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_7u2kLyWc, 0, m, &cIf_7u2kLyWc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HqNajfCt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GzDgAnp7, HV_BINOP_POW, 1, m, &cBinop_GzDgAnp7_sendMessage);
  cMsg_e6ebnWB2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_7u2kLyWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZNgsskTv_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z3ThGhEh_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_MxHcE190_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_UxpIki8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qKRDJJ17, 1, m, &cIf_qKRDJJ17_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1o09Sl3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ad7NKOhP, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Ad7NKOhP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZ5fJkYO, HV_BINOP_EQ, 1, m, &cBinop_DZ5fJkYO_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ul9q4giv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_3w2ggab1, HV_BINOP_ADD, 0, m, &cBinop_3w2ggab1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3w2ggab1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y7nMt5nR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QE7j4osw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ad7NKOhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_7u2kLyWc, 1, m, &cIf_7u2kLyWc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DZ5fJkYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_eTPFGbEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_eTPFGbEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ZNgsskTv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_z3ThGhEh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_MxHcE190_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ptd7WS2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tng9yCCf, 0, m, &cVar_Tng9yCCf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V14IIHo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ul9q4giv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_9oeqDr1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3w2ggab1, HV_BINOP_ADD, 1, m, &cBinop_3w2ggab1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ad7NKOhP, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Ad7NKOhP_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DZ5fJkYO, HV_BINOP_EQ, 0, m, &cBinop_DZ5fJkYO_sendMessage);
}

void Heavy_WSTD_EQ::cVar_aixrSF8k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Of5uvdMq_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_gpwGoKzW, 0, m, &cIf_gpwGoKzW_sendMessage);
}

void Heavy_WSTD_EQ::cIf_gpwGoKzW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_OZvDoZFC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_eggk3yR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_lfFJML6Q_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_a72SvWF8_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_UyaNQRB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_k5Sp29DA, HV_BINOP_POW, 0, m, &cBinop_k5Sp29DA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k5Sp29DA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aB9Qs7mF, 0, m, &cIf_aB9Qs7mF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0OmNMh7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_gbeAofTZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hQP2CGBC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_1UfOpIXy_sendMessage);
}

void Heavy_WSTD_EQ::cCast_n0x2RLYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eggk3yR1, 0, m, &cIf_eggk3yR1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1UfOpIXy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eggk3yR1, 1, m, &cIf_eggk3yR1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_a72SvWF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_0OmNMh7l_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lfFJML6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_aB9Qs7mF, 0, m, &cIf_aB9Qs7mF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gbeAofTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_k5Sp29DA, HV_BINOP_POW, 1, m, &cBinop_k5Sp29DA_sendMessage);
  cMsg_UyaNQRB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_aB9Qs7mF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_fDO0pHfw, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_Of5uvdMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gpwGoKzW, 1, m, &cIf_gpwGoKzW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OZvDoZFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7WrD63M, HV_BINOP_GREATER_THAN, 1, m, &cBinop_C7WrD63M_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q0Hzq6dN, HV_BINOP_EQ, 1, m, &cBinop_q0Hzq6dN_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_A21SOp3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_h21F7B3i, HV_BINOP_ADD, 0, m, &cBinop_h21F7B3i_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h21F7B3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hQP2CGBC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n0x2RLYy_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C7WrD63M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aB9Qs7mF, 1, m, &cIf_aB9Qs7mF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q0Hzq6dN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JlvRE9pL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_JlvRE9pL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_fDO0pHfw, m);
}

void Heavy_WSTD_EQ::cCast_YfCRPQF9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aixrSF8k, 0, m, &cVar_aixrSF8k_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xICx9pXl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_A21SOp3g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_8Qoh9cft_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h21F7B3i, HV_BINOP_ADD, 1, m, &cBinop_h21F7B3i_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_C7WrD63M, HV_BINOP_GREATER_THAN, 0, m, &cBinop_C7WrD63M_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_q0Hzq6dN, HV_BINOP_EQ, 0, m, &cBinop_q0Hzq6dN_sendMessage);
}

void Heavy_WSTD_EQ::cIf_hjpMuCTo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_iwPjuLCM, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_RVxSWYYT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CUcn2IEb, 0, m, &cSlice_CUcn2IEb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_g52rBLl9_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_CUcn2IEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_kEeH992L_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_kEeH992L_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_LMLllTOr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kEeH992L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_kEeH992L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lT1IuJrW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_g52rBLl9_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XU8rIZZb, 0, m, &cSlice_XU8rIZZb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_rthMRaJv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_XU8rIZZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_EK4ZzRue_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_EK4ZzRue_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_dxtxzrHW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_EK4ZzRue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_EK4ZzRue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_33sEnqTa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_oZse9ECt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BBaVcrJ3, 0, m, &cSlice_BBaVcrJ3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YxAscSS0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_BBaVcrJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_RqmztFja_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_RqmztFja_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_cGPdl36I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_RqmztFja_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_RqmztFja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_f9qg56YQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_YxAscSS0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7f7ghyC6, 0, m, &cSlice_7f7ghyC6_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_7f7ghyC6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fjQmTALC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fjQmTALC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_PQRetnKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fjQmTALC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fjQmTALC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UHqiu6CZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_Ra2I9ZNS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_c0D79il9, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_dkArlce6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iJHKU8Ge, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qjXJ0ZXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TXpf2yq6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_xFYB2xKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_i0ebYvao, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_DoCvvTtV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vEq87I65, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_tAcYnHoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_j6Ho33ct_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_j6Ho33ct_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u5NhFKrq, HV_BINOP_DIVIDE, 1, m, &cBinop_u5NhFKrq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EA9TH2JV_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_11eFKYyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_i9xPbcZl_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_X1YDLwNc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_11eFKYyH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i9xPbcZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u5NhFKrq, HV_BINOP_DIVIDE, 0, m, &cBinop_u5NhFKrq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EA9TH2JV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_X1YDLwNc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_u5NhFKrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K9oR3cfc, HV_BINOP_MULTIPLY, 1, m, &cBinop_K9oR3cfc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K9oR3cfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pjJCyGhe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XpqxPf5R_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_3loIzBMF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sdY15pRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_FDj2r9pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0EgB2OrQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_BaLsXlRS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_dGqQzZIp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dGqQzZIp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K9oR3cfc, HV_BINOP_MULTIPLY, 0, m, &cBinop_K9oR3cfc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mTeQWixS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mUXIzNzF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mUXIzNzF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JB7BXbNr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NcDRhYWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wnzkJqqd, 1, m, &cVar_wnzkJqqd_sendMessage);
}

void Heavy_WSTD_EQ::cVar_wnzkJqqd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjN2A5jJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_S9ztWMGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_moh6ecYP, HV_BINOP_MULTIPLY, 1, m, &cBinop_moh6ecYP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QUXpZT2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_S9ztWMGP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DoawhcMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ysRHIvAQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ysRHIvAQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_10l7gDFs, HV_BINOP_MULTIPLY, 1, m, &cBinop_10l7gDFs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_US8Zm81f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ugk1lX4, HV_BINOP_MULTIPLY, 1, m, &cBinop_1Ugk1lX4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RmBe1NoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_US8Zm81f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gEXhhLLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXBtsh0X, HV_BINOP_MULTIPLY, 1, m, &cBinop_vXBtsh0X_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ZWG3ZnPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_9VcyCyJw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9VcyCyJw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_46cRf48E, HV_BINOP_MULTIPLY, 1, m, &cBinop_46cRf48E_sendMessage);
}

void Heavy_WSTD_EQ::cVar_fe8nX5oe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9EuBzLhP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_BaLsXlRS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TzwCceSl_sendMessage);
}

void Heavy_WSTD_EQ::cVar_JOf1p8lt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_mTeQWixS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pjJCyGhe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_3loIzBMF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XpqxPf5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_FDj2r9pN_sendMessage);
}

void Heavy_WSTD_EQ::cSend_sdY15pRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_e8mPZ16X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_0EgB2OrQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HUt1RYK2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_jKvN6LD7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CAMma95i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_JB7BXbNr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_k126DJPb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_k126DJPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xzmE9vN7, HV_BINOP_MULTIPLY, 1, m, &cBinop_xzmE9vN7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xzmE9vN7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hjRxQDkG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hjRxQDkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_jKvN6LD7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_SjN2A5jJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_VxirrVEY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VxirrVEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vLIMXGeR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VgBC2zEu_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6YxYMdqq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nQvK0jw8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3ZB1ITGT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BbZS51ac_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_moh6ecYP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ra2I9ZNS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_10l7gDFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dkArlce6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_1Ugk1lX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qjXJ0ZXJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vXBtsh0X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xFYB2xKt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_46cRf48E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DoCvvTtV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_zLOptZnq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_fe8nX5oe, 0, m, &cVar_fe8nX5oe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SNDnNTQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JOf1p8lt, 1, m, &cVar_JOf1p8lt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6YxYMdqq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vXBtsh0X, HV_BINOP_MULTIPLY, 0, m, &cBinop_vXBtsh0X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3ZB1ITGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_10l7gDFs, HV_BINOP_MULTIPLY, 0, m, &cBinop_10l7gDFs_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nQvK0jw8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1Ugk1lX4, HV_BINOP_MULTIPLY, 0, m, &cBinop_1Ugk1lX4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BbZS51ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_moh6ecYP, HV_BINOP_MULTIPLY, 0, m, &cBinop_moh6ecYP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vLIMXGeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_VgBC2zEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_46cRf48E, HV_BINOP_MULTIPLY, 0, m, &cBinop_46cRf48E_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9EuBzLhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JOf1p8lt, 0, m, &cVar_JOf1p8lt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TzwCceSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_wnzkJqqd, 0, m, &cVar_wnzkJqqd_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_tDgSXrhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bgJorfWO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BTVlo7ut_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_heJqhLPw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_qgHapuog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SInEiuYb, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ZKToY5TM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CfufUUbm, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UYFGHQUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7sl1qZJj_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_7sl1qZJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xJfF3X2, HV_BINOP_DIVIDE, 1, m, &cBinop_5xJfF3X2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5sRgHkxJ_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_9x6sK0Ik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_yPSs7Y9F_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EqTlfeog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_9x6sK0Ik_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yPSs7Y9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5xJfF3X2, HV_BINOP_DIVIDE, 0, m, &cBinop_5xJfF3X2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5sRgHkxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EqTlfeog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_5xJfF3X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3QByPr1, HV_BINOP_MULTIPLY, 1, m, &cBinop_z3QByPr1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_z3QByPr1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cHa64AhQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F0DIbcLP_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_arnoHZbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_a2vzF2hF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_kOklj96P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_TqVrgQZl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_w0uRbMxF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_HAF8cjMs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HAF8cjMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z3QByPr1, HV_BINOP_MULTIPLY, 0, m, &cBinop_z3QByPr1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ogKNYVOm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_iBib8VLj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iBib8VLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5EfbSNoD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_2DImVkgM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PA5vXQGW, HV_BINOP_MULTIPLY, 1, m, &cBinop_PA5vXQGW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_y7EsJPsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8KlFrx6, 1, m, &cVar_e8KlFrx6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5pqFuDpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTzkABYt, HV_BINOP_MULTIPLY, 1, m, &cBinop_GTzkABYt_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lpVCckYQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LuEzwqde_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LuEzwqde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ek7kOCWh, HV_BINOP_MULTIPLY, 1, m, &cBinop_ek7kOCWh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_e8KlFrx6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OlRw5T4T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_tLe9Ouqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SyoQ0pEA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_w0uRbMxF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EkCJQz5V_sendMessage);
}

void Heavy_WSTD_EQ::cVar_d2Q5PqAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_ogKNYVOm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_F0DIbcLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_kOklj96P_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cHa64AhQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_arnoHZbK_sendMessage);
}

void Heavy_WSTD_EQ::cSend_a2vzF2hF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EGRTDO8x_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_TqVrgQZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YE2MqUs5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_B0Xn0BYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xBbUlcUK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_5EfbSNoD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_NbxOdD6Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NbxOdD6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYGDPcmj, HV_BINOP_MULTIPLY, 1, m, &cBinop_yYGDPcmj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yYGDPcmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eVAObgiq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eVAObgiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_B0Xn0BYq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_OlRw5T4T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XZvOxiWK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XZvOxiWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MwCwRldV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5lHTrmC_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYmSN0og_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_94ZyV4bI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HU4rgvVd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tDgSXrhI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PA5vXQGW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BTVlo7ut_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_GTzkABYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qgHapuog_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ek7kOCWh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZKToY5TM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_j7EwrwNe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tLe9Ouqn, 0, m, &cVar_tLe9Ouqn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mBFnfWKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d2Q5PqAI, 1, m, &cVar_d2Q5PqAI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SyoQ0pEA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_d2Q5PqAI, 0, m, &cVar_d2Q5PqAI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EkCJQz5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_e8KlFrx6, 0, m, &cVar_e8KlFrx6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_m5lHTrmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GTzkABYt, HV_BINOP_MULTIPLY, 0, m, &cBinop_GTzkABYt_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MwCwRldV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ek7kOCWh, HV_BINOP_MULTIPLY, 0, m, &cBinop_ek7kOCWh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_94ZyV4bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU4rgvVd, HV_BINOP_MULTIPLY, 0, m, &cBinop_HU4rgvVd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eYmSN0og_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PA5vXQGW, HV_BINOP_MULTIPLY, 0, m, &cBinop_PA5vXQGW_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EbmzYGup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9rwB7HSw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QvU4GoVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KyGvW0jx, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_QdFBOks4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RbdekJqV, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bW4pViDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rLKg8pux, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AAclmSix_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sbhNeIwL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9UuUXMk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_KCrFY8CD_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_KCrFY8CD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEIeq0XB, HV_BINOP_DIVIDE, 1, m, &cBinop_xEIeq0XB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zIM2ETbH_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_BWjEb94f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KeymLbuw_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XisRQCal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_BWjEb94f_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KeymLbuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xEIeq0XB, HV_BINOP_DIVIDE, 0, m, &cBinop_xEIeq0XB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zIM2ETbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XisRQCal_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xEIeq0XB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GODhRRs2, HV_BINOP_MULTIPLY, 1, m, &cBinop_GODhRRs2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GODhRRs2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4fiaUnoz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nToAaLAP_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_LsBeOnGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MiH7EISr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_ytpzIsfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_En71qctb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cYciMcGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Stuz4SRZ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Stuz4SRZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GODhRRs2, HV_BINOP_MULTIPLY, 0, m, &cBinop_GODhRRs2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QSaNiFcS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_85nQJyPR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_85nQJyPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_N35Q3Qcf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vRG4lySq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kAl2jIv, HV_BINOP_MULTIPLY, 1, m, &cBinop_5kAl2jIv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_db8X8vK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_JiC7pFRo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JiC7pFRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vRG4lySq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_n5MNrehs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_AZiMkBmd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AZiMkBmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8owc6Qj, HV_BINOP_MULTIPLY, 1, m, &cBinop_y8owc6Qj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L96rODy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_77PAC1JB, HV_BINOP_MULTIPLY, 1, m, &cBinop_77PAC1JB_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_4nj8CnaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nglyN17m_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nglyN17m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_L96rODy9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pQN1YH7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pi6vq9V, 1, m, &cVar_7pi6vq9V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LIGUR9fG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTPkBO3z, HV_BINOP_MULTIPLY, 1, m, &cBinop_FTPkBO3z_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_MR3KrgGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5oZrCqya_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5oZrCqya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qcg8pryV, HV_BINOP_MULTIPLY, 1, m, &cBinop_qcg8pryV_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7pi6vq9V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jA9o4ahq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ixq7xj8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jqIwqPVv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cYciMcGq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EPV8vkoY_sendMessage);
}

void Heavy_WSTD_EQ::cVar_2DaJTWSl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_QSaNiFcS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nToAaLAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_ytpzIsfz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4fiaUnoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_LsBeOnGm_sendMessage);
}

void Heavy_WSTD_EQ::cSend_MiH7EISr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JJjxXPcQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_En71qctb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YOzNjm9l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NCFzbaG3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2g4oLSr0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_N35Q3Qcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_lJfHAGio_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lJfHAGio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yJBfmgWO, HV_BINOP_MULTIPLY, 1, m, &cBinop_yJBfmgWO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yJBfmgWO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_vQUVa5hc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vQUVa5hc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NCFzbaG3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_jA9o4ahq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9VhRg6bP_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9VhRg6bP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5AoOYRUB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GRnefHuV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9G53COYh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M81sI5dz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q7eOb3UF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9VQmZBwh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5kAl2jIv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EbmzYGup_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_y8owc6Qj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QvU4GoVC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_77PAC1JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QdFBOks4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_FTPkBO3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bW4pViDe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_qcg8pryV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AAclmSix_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_E9qcEHGQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2DaJTWSl, 1, m, &cVar_2DaJTWSl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_vnv8SGDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ixq7xj8e, 0, m, &cVar_ixq7xj8e_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9G53COYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FTPkBO3z, HV_BINOP_MULTIPLY, 0, m, &cBinop_FTPkBO3z_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5AoOYRUB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_GRnefHuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qcg8pryV, HV_BINOP_MULTIPLY, 0, m, &cBinop_qcg8pryV_sendMessage);
}

void Heavy_WSTD_EQ::cCast_q7eOb3UF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y8owc6Qj, HV_BINOP_MULTIPLY, 0, m, &cBinop_y8owc6Qj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_M81sI5dz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_77PAC1JB, HV_BINOP_MULTIPLY, 0, m, &cBinop_77PAC1JB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9VQmZBwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5kAl2jIv, HV_BINOP_MULTIPLY, 0, m, &cBinop_5kAl2jIv_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jqIwqPVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2DaJTWSl, 0, m, &cVar_2DaJTWSl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EPV8vkoY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7pi6vq9V, 0, m, &cVar_7pi6vq9V_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZNgsskTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hjpMuCTo, 1, m, &cIf_hjpMuCTo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_06mzYxGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iwPjuLCM, m);
}

void Heavy_WSTD_EQ::cBinop_z3ThGhEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_06mzYxGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MxHcE190_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hjpMuCTo, 0, m, &cIf_hjpMuCTo_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_604Q60Kq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_PIo28quH, 0, m, &cSlice_PIo28quH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_o21fz5z7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_PIo28quH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OWSs9ODG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OWSs9ODG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_2mY3uXHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OWSs9ODG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_OWSs9ODG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_FAwz3Gku_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_3nVE2R10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cf2aV0Bh_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_girpIGHq, 0, m, &cIf_girpIGHq_sendMessage);
}

void Heavy_WSTD_EQ::cIf_girpIGHq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_o8BrTST3_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_F1u7H5jR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qGZbKE8z_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_2Htn6NBZ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_0IawjZfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OIMmzpMm, HV_BINOP_POW, 0, m, &cBinop_OIMmzpMm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OIMmzpMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_79GEc8zL, 0, m, &cIf_79GEc8zL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_21eCGYpj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_HcI89s7l_sendMessage);
}

void Heavy_WSTD_EQ::cCast_V9Awlg9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F1u7H5jR, 0, m, &cIf_F1u7H5jR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_m5x9Y3gq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Yg9kd1NI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Yg9kd1NI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_F1u7H5jR, 1, m, &cIf_F1u7H5jR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2Htn6NBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_21eCGYpj_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_qGZbKE8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_79GEc8zL, 0, m, &cIf_79GEc8zL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HcI89s7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OIMmzpMm, HV_BINOP_POW, 1, m, &cBinop_OIMmzpMm_sendMessage);
  cMsg_0IawjZfg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_79GEc8zL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_W1UeyKoj, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_cf2aV0Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_girpIGHq, 1, m, &cIf_girpIGHq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_o8BrTST3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vEaWEH5U, HV_BINOP_GREATER_THAN, 1, m, &cBinop_vEaWEH5U_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZG20ocI, HV_BINOP_EQ, 1, m, &cBinop_xZG20ocI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_7KBSMvJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWb2tPIQ, HV_BINOP_ADD, 0, m, &cBinop_dWb2tPIQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_dWb2tPIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_m5x9Y3gq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_V9Awlg9C_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vEaWEH5U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_79GEc8zL, 1, m, &cIf_79GEc8zL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xZG20ocI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mSwOesLy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_mSwOesLy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_W1UeyKoj, m);
}

void Heavy_WSTD_EQ::cCast_8kYGmWfg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7KBSMvJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_pkJcfOFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWb2tPIQ, HV_BINOP_ADD, 1, m, &cBinop_dWb2tPIQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_vEaWEH5U, HV_BINOP_GREATER_THAN, 0, m, &cBinop_vEaWEH5U_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xZG20ocI, HV_BINOP_EQ, 0, m, &cBinop_xZG20ocI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FlF96X0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3nVE2R10, 0, m, &cVar_3nVE2R10_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7T5w2nk9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GGwuaAvD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_99MOijmF, 0, m, &cIf_99MOijmF_sendMessage);
}

void Heavy_WSTD_EQ::cIf_99MOijmF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_HFY35nrd_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_twjGqtWk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Pg50ZmOe_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_3mtxXpc6_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_5i8cCgJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HJeIvwna, HV_BINOP_POW, 0, m, &cBinop_HJeIvwna_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HJeIvwna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6A9iE4w0, 0, m, &cIf_6A9iE4w0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pDRDu1Zq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Cpj77hK4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pROw1D1z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_twjGqtWk, 0, m, &cIf_twjGqtWk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XFVsjC8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_UdGW55Ol_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UdGW55Ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_twjGqtWk, 1, m, &cIf_twjGqtWk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3mtxXpc6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_pDRDu1Zq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Pg50ZmOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_6A9iE4w0, 0, m, &cIf_6A9iE4w0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Cpj77hK4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HJeIvwna, HV_BINOP_POW, 1, m, &cBinop_HJeIvwna_sendMessage);
  cMsg_5i8cCgJl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_6A9iE4w0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qZh88TWS_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nokqIgtY_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6HcG0iVf_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_GGwuaAvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_99MOijmF, 1, m, &cIf_99MOijmF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HFY35nrd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wTA3gpPS, HV_BINOP_GREATER_THAN, 1, m, &cBinop_wTA3gpPS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AqFMA4ra, HV_BINOP_EQ, 1, m, &cBinop_AqFMA4ra_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JA2Hmoab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0MstwEv, HV_BINOP_ADD, 0, m, &cBinop_p0MstwEv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p0MstwEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XFVsjC8Y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pROw1D1z_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wTA3gpPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6A9iE4w0, 1, m, &cIf_6A9iE4w0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AqFMA4ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7s4DyotY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_7s4DyotY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_qZh88TWS_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_nokqIgtY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_6HcG0iVf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XRPLeorF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7T5w2nk9, 0, m, &cVar_7T5w2nk9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Wu56VW15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JA2Hmoab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_35VBTYXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p0MstwEv, HV_BINOP_ADD, 1, m, &cBinop_p0MstwEv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_wTA3gpPS, HV_BINOP_GREATER_THAN, 0, m, &cBinop_wTA3gpPS_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_AqFMA4ra, HV_BINOP_EQ, 0, m, &cBinop_AqFMA4ra_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YMeeuotE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_C7CBWa1p_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_n6FbCfgY, 0, m, &cIf_n6FbCfgY_sendMessage);
}

void Heavy_WSTD_EQ::cIf_n6FbCfgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_SZeP9FRo_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_xRJM3Rc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_RU3fKISd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_QXcm8ycC_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_73fzpBlx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6TwdKWB, HV_BINOP_POW, 0, m, &cBinop_R6TwdKWB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_R6TwdKWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9lsWEuX8, 0, m, &cIf_9lsWEuX8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uG0nSF87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_52w3xTca_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6VJCGxfl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xRJM3Rc1, 0, m, &cIf_xRJM3Rc1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EUqTOdh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7feZPh3w_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7feZPh3w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xRJM3Rc1, 1, m, &cIf_xRJM3Rc1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QXcm8ycC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_uG0nSF87_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_RU3fKISd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_9lsWEuX8, 0, m, &cIf_9lsWEuX8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_52w3xTca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_R6TwdKWB, HV_BINOP_POW, 1, m, &cBinop_R6TwdKWB_sendMessage);
  cMsg_73fzpBlx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_9lsWEuX8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_MBn5APwX, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_C7CBWa1p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n6FbCfgY, 1, m, &cIf_n6FbCfgY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SZeP9FRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKLIpdWY, HV_BINOP_GREATER_THAN, 1, m, &cBinop_XKLIpdWY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hi6MkPa1, HV_BINOP_EQ, 1, m, &cBinop_Hi6MkPa1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_GTAvQK4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAKSb3ol, HV_BINOP_ADD, 0, m, &cBinop_xAKSb3ol_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xAKSb3ol_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EUqTOdh0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6VJCGxfl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XKLIpdWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9lsWEuX8, 1, m, &cIf_9lsWEuX8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hi6MkPa1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fxBUP3RG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fxBUP3RG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_MBn5APwX, m);
}

void Heavy_WSTD_EQ::cCast_lXaaePtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GTAvQK4I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_rPZRJ6QH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAKSb3ol, HV_BINOP_ADD, 1, m, &cBinop_xAKSb3ol_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_XKLIpdWY, HV_BINOP_GREATER_THAN, 0, m, &cBinop_XKLIpdWY_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Hi6MkPa1, HV_BINOP_EQ, 0, m, &cBinop_Hi6MkPa1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_0Jkf7nCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YMeeuotE, 0, m, &cVar_YMeeuotE_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ceZII5eP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_RLOhNWu9, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_MjOahGHD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_g4H0SfHm, 0, m, &cSlice_g4H0SfHm_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Et4DBtUi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_g4H0SfHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2ZFD5WPc_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2ZFD5WPc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_RcgX1ahg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2ZFD5WPc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_2ZFD5WPc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tR379nMM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_Et4DBtUi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xl44DChN, 0, m, &cSlice_xl44DChN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_604Q60Kq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_xl44DChN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hskLmkGJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hskLmkGJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_rV8QODXN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hskLmkGJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_hskLmkGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uirGeezY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_o21fz5z7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9W363Flq, 0, m, &cSlice_9W363Flq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1PUHQ30n_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_9W363Flq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_j00LPDrz_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_j00LPDrz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_q4QL9SrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_j00LPDrz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_j00LPDrz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jq0m9rwu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_1PUHQ30n_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_BFSuPpTH, 0, m, &cSlice_BFSuPpTH_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_BFSuPpTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fHa3HbkL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fHa3HbkL_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_eFySdU4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fHa3HbkL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_fHa3HbkL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uxTmbK4q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_nB6NErAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HXyEHTNa, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_BP4PbJKA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SUww0ejw, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ULhBvMiE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bbHbNLmD, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AfhWCImw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ui27WL2g, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Lkce1zhm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bviSj19E, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_CHlf9OiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_DheonKHA_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_DheonKHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3WvPKMl, HV_BINOP_DIVIDE, 1, m, &cBinop_h3WvPKMl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NyedcQ9w_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_hKnVeQMc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_tXfCrbkK_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2I5y6WNp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_hKnVeQMc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tXfCrbkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h3WvPKMl, HV_BINOP_DIVIDE, 0, m, &cBinop_h3WvPKMl_sendMessage);
}

void Heavy_WSTD_EQ::cCast_NyedcQ9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2I5y6WNp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_h3WvPKMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mKvVwxhB, HV_BINOP_MULTIPLY, 1, m, &cBinop_mKvVwxhB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mKvVwxhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fzqqTsmQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Iet03Ivm_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_rQ9iDyXC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_J1TsLNV9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_nbAmhFCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_1cGwpibB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_SfD3Ovai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_3wqL1akq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3wqL1akq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mKvVwxhB, HV_BINOP_MULTIPLY, 0, m, &cBinop_mKvVwxhB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_GsmVHPiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_cQlHC4jQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cQlHC4jQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h4Jzos0c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_LZgW27sQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6AINDqTD, 1, m, &cVar_6AINDqTD_sendMessage);
}

void Heavy_WSTD_EQ::cVar_6AINDqTD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_phfOFc20_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hSX2Hqc9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smSiLvBU, HV_BINOP_MULTIPLY, 1, m, &cBinop_smSiLvBU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NEsQ0UOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hSX2Hqc9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oMo5D8Wr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_FP16Y05L_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FP16Y05L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAW8G9Ql, HV_BINOP_MULTIPLY, 1, m, &cBinop_DAW8G9Ql_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Zyp6Gjfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VhifYRTj, HV_BINOP_MULTIPLY, 1, m, &cBinop_VhifYRTj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q84Xe37I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Zyp6Gjfv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SKa5t84C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xnWVfIuX, HV_BINOP_MULTIPLY, 1, m, &cBinop_xnWVfIuX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_QYnJSciL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NnfxmoLr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NnfxmoLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hyCEEdFF, HV_BINOP_MULTIPLY, 1, m, &cBinop_hyCEEdFF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lJsYf6rP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dP8cOF95_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SfD3Ovai_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XSc8sIIy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_WM6Ixemo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_GsmVHPiq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Iet03Ivm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nbAmhFCG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_fzqqTsmQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_rQ9iDyXC_sendMessage);
}

void Heavy_WSTD_EQ::cSend_J1TsLNV9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_DfpEXY2n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_1cGwpibB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gh6Lgw7W_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JocsqKAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kyHn4l1X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_h4Jzos0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_5cbvcFuw_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5cbvcFuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StxNVpFr, HV_BINOP_MULTIPLY, 1, m, &cBinop_StxNVpFr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_StxNVpFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7oRONXJk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7oRONXJk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JocsqKAn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_phfOFc20_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RuddYvHa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RuddYvHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hEHPoPg1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5j6i0UgX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ovjy49ee_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ADR5a8kz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wdPNCwxt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_K54uAz8g_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_smSiLvBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nB6NErAL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DAW8G9Ql_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BP4PbJKA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VhifYRTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ULhBvMiE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xnWVfIuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AfhWCImw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_hyCEEdFF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lkce1zhm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_zAgJhkE8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WM6Ixemo, 1, m, &cVar_WM6Ixemo_sendMessage);
}

void Heavy_WSTD_EQ::cCast_yDqCr4EY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lJsYf6rP, 0, m, &cVar_lJsYf6rP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ADR5a8kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VhifYRTj, HV_BINOP_MULTIPLY, 0, m, &cBinop_VhifYRTj_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5j6i0UgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hyCEEdFF, HV_BINOP_MULTIPLY, 0, m, &cBinop_hyCEEdFF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hEHPoPg1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_wdPNCwxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DAW8G9Ql, HV_BINOP_MULTIPLY, 0, m, &cBinop_DAW8G9Ql_sendMessage);
}

void Heavy_WSTD_EQ::cCast_K54uAz8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_smSiLvBU, HV_BINOP_MULTIPLY, 0, m, &cBinop_smSiLvBU_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Ovjy49ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xnWVfIuX, HV_BINOP_MULTIPLY, 0, m, &cBinop_xnWVfIuX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XSc8sIIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6AINDqTD, 0, m, &cVar_6AINDqTD_sendMessage);
}

void Heavy_WSTD_EQ::cCast_dP8cOF95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WM6Ixemo, 0, m, &cVar_WM6Ixemo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_UKxJDaPI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2495c0hI, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_IGDI6GJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_NDMk3al6, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_UUUe9Oue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rJmf5G3O, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_bzrVxrRX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_33mfSqbe, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_AO7JcE6h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_68rYn1yd_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_68rYn1yd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAdA3wmB, HV_BINOP_DIVIDE, 1, m, &cBinop_xAdA3wmB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LM8XLX01_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_xqDUpbtU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_0kiPOs4Y_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_yjYZJJiW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_xqDUpbtU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0kiPOs4Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xAdA3wmB, HV_BINOP_DIVIDE, 0, m, &cBinop_xAdA3wmB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LM8XLX01_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yjYZJJiW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xAdA3wmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ngk2Uz92, HV_BINOP_MULTIPLY, 1, m, &cBinop_ngk2Uz92_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ngk2Uz92_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gDLt5Mmt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aErMVIth_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_Zb1EBZwq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Lo76tSoP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_872W5if6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_LNteIlvs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XSthjKth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Fm8Bc8N2_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fm8Bc8N2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ngk2Uz92, HV_BINOP_MULTIPLY, 0, m, &cBinop_ngk2Uz92_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O2MaZBj3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_njznbR3B_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_njznbR3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V39Ip7WA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vjCalB2S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5mwRioV, HV_BINOP_MULTIPLY, 1, m, &cBinop_M5mwRioV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_K9eCErwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OvRqKk8G, 1, m, &cVar_OvRqKk8G_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HhbMlXkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfrvyB0c, HV_BINOP_MULTIPLY, 1, m, &cBinop_OfrvyB0c_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_1sM2qmsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TDp118a8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TDp118a8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tD3peYXR, HV_BINOP_MULTIPLY, 1, m, &cBinop_tD3peYXR_sendMessage);
}

void Heavy_WSTD_EQ::cVar_OvRqKk8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8ZT17w6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_a4KAFqoa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CNmLnWmn_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XSthjKth_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JLt31ruu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_rjXTWBEc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_O2MaZBj3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gDLt5Mmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_Zb1EBZwq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aErMVIth_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_872W5if6_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Lo76tSoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T5mOEu8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_LNteIlvs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A0HwPEwY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CQ40ocua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_kktaTeQL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_V39Ip7WA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mdbnPy15_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mdbnPy15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6bF1RLVJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_6bF1RLVJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6bF1RLVJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_iPXEEbcp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iPXEEbcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CQ40ocua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_u8ZT17w6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_eeasFlIf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_eeasFlIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VODgcnNl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HGnsaEYa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_I6tERfmO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5S3qiMJs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_O71JH1n4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UKxJDaPI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_M5mwRioV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IGDI6GJe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_OfrvyB0c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UUUe9Oue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tD3peYXR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bzrVxrRX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_W8ob96az_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a4KAFqoa, 0, m, &cVar_a4KAFqoa_sendMessage);
}

void Heavy_WSTD_EQ::cCast_mK9JJCeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rjXTWBEc, 1, m, &cVar_rjXTWBEc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_CNmLnWmn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rjXTWBEc, 0, m, &cVar_rjXTWBEc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_JLt31ruu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OvRqKk8G, 0, m, &cVar_OvRqKk8G_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VODgcnNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tD3peYXR, HV_BINOP_MULTIPLY, 0, m, &cBinop_tD3peYXR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5S3qiMJs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O71JH1n4, HV_BINOP_MULTIPLY, 0, m, &cBinop_O71JH1n4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_HGnsaEYa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OfrvyB0c, HV_BINOP_MULTIPLY, 0, m, &cBinop_OfrvyB0c_sendMessage);
}

void Heavy_WSTD_EQ::cCast_I6tERfmO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_M5mwRioV, HV_BINOP_MULTIPLY, 0, m, &cBinop_M5mwRioV_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Si5MWy5z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_watCYEHl, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3vocsqab_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_th5WwSIZ, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3hX01NIF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2aRaU7th, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_FCOs9qsP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ff3QFqiy, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SSCZuFNd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tTPO4ZQO, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ANI3HLxK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_1CVGD2ES_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_1CVGD2ES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQdIw3Q3, HV_BINOP_DIVIDE, 1, m, &cBinop_vQdIw3Q3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BqlReucw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_29xMvMYt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_9m2FTNxn_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_nRlhR392_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_29xMvMYt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9m2FTNxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vQdIw3Q3, HV_BINOP_DIVIDE, 0, m, &cBinop_vQdIw3Q3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BqlReucw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRlhR392_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_vQdIw3Q3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wrhng7Oz, HV_BINOP_MULTIPLY, 1, m, &cBinop_wrhng7Oz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wrhng7Oz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UEPOgEKG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iPoYx0WN_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_lwUZRIVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uqiWMkr2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_9qYjAVrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7VtYxc3I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_cWPdGYRU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_oD5uXUqF_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oD5uXUqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wrhng7Oz, HV_BINOP_MULTIPLY, 0, m, &cBinop_wrhng7Oz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0JmMIthM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_JibSxRcX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JibSxRcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cHCfEG7H_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bJ3X1oMi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPnbjdet, HV_BINOP_MULTIPLY, 1, m, &cBinop_pPnbjdet_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2qcvY6iQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kAOi8ecQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kAOi8ecQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bJ3X1oMi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_8AvsvqxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2Idud7PB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2Idud7PB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W9BVg9c0, HV_BINOP_MULTIPLY, 1, m, &cBinop_W9BVg9c0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5Jv3EC3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j9jlasho, HV_BINOP_MULTIPLY, 1, m, &cBinop_j9jlasho_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mkFoDpQS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kcWF8nDj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kcWF8nDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5Jv3EC3U_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_srOtpJtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zHJLvZm, 1, m, &cVar_7zHJLvZm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_17Esko6k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nlTbFrXF, HV_BINOP_MULTIPLY, 1, m, &cBinop_nlTbFrXF_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_McXLazgz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_sh8W71nJ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_sh8W71nJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z6sdrS8K, HV_BINOP_MULTIPLY, 1, m, &cBinop_z6sdrS8K_sendMessage);
}

void Heavy_WSTD_EQ::cVar_7zHJLvZm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M2zuOjOQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_yEi1Z692_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PxKZrkv1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_cWPdGYRU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OwaoWtvF_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lT7vg5pk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_0JmMIthM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_iPoYx0WN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9qYjAVrf_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UEPOgEKG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_lwUZRIVs_sendMessage);
}

void Heavy_WSTD_EQ::cSend_uqiWMkr2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_8IlsaEAR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7VtYxc3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_uDBTjqZ3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_zxoWe7R1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R3scQNGK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_cHCfEG7H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_mzIsT6Xe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mzIsT6Xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lVM54YI0, HV_BINOP_MULTIPLY, 1, m, &cBinop_lVM54YI0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lVM54YI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1SAzhrmC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1SAzhrmC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zxoWe7R1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_M2zuOjOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_wMWIENLt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_wMWIENLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IACMoBAW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Dj0U0OQb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PfOzMUsy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aoChITow_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7HpD6zfP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ihUJgCxq_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pPnbjdet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Si5MWy5z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_W9BVg9c0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3vocsqab_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_j9jlasho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3hX01NIF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_nlTbFrXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FCOs9qsP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_z6sdrS8K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SSCZuFNd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_G1GF9AcI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yEi1Z692, 0, m, &cVar_yEi1Z692_sendMessage);
}

void Heavy_WSTD_EQ::cCast_I6gsx2mI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lT7vg5pk, 1, m, &cVar_lT7vg5pk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PfOzMUsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nlTbFrXF, HV_BINOP_MULTIPLY, 0, m, &cBinop_nlTbFrXF_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aoChITow_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_j9jlasho, HV_BINOP_MULTIPLY, 0, m, &cBinop_j9jlasho_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ihUJgCxq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pPnbjdet, HV_BINOP_MULTIPLY, 0, m, &cBinop_pPnbjdet_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IACMoBAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_Dj0U0OQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_z6sdrS8K, HV_BINOP_MULTIPLY, 0, m, &cBinop_z6sdrS8K_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7HpD6zfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W9BVg9c0, HV_BINOP_MULTIPLY, 0, m, &cBinop_W9BVg9c0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OwaoWtvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_7zHJLvZm, 0, m, &cVar_7zHJLvZm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_PxKZrkv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lT7vg5pk, 0, m, &cVar_lT7vg5pk_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qZh88TWS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ceZII5eP, 1, m, &cIf_ceZII5eP_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_TCEw7CPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_RLOhNWu9, m);
}

void Heavy_WSTD_EQ::cBinop_nokqIgtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TCEw7CPr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6HcG0iVf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ceZII5eP, 0, m, &cIf_ceZII5eP_sendMessage);
}

void Heavy_WSTD_EQ::cVar_DJYcNqPb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ok1HEJgH, HV_BINOP_DIVIDE, 0, m, &cBinop_ok1HEJgH_sendMessage);
}

void Heavy_WSTD_EQ::cVar_2ie0wll8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0z1cpKoC, HV_BINOP_DIVIDE, 1, m, &cBinop_0z1cpKoC_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ok1HEJgH, HV_BINOP_DIVIDE, 1, m, &cBinop_ok1HEJgH_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_YG8z0mnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOpgQnCS, HV_BINOP_DIVIDE, 0, m, &cBinop_lOpgQnCS_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_NHKeRiMz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lOpgQnCS, HV_BINOP_DIVIDE, 1, m, &cBinop_lOpgQnCS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_i1kldreE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2ie0wll8, 0, m, &cVar_2ie0wll8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_aLKsMRlq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DJYcNqPb, 0, m, &cVar_DJYcNqPb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_bZBocYwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0z1cpKoC, HV_BINOP_DIVIDE, 0, m, &cBinop_0z1cpKoC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0z1cpKoC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_YG8z0mnA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ok1HEJgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_NHKeRiMz_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_lOpgQnCS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_KRy7bXjA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_iqXjszDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_nuckqBMo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_1ewOXt2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_8eZ8dCwQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KRy7bXjA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_1ewOXt2h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8eZ8dCwQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_iqXjszDb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nuckqBMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_O0KjohsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_P3osyH7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVxSWYYT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MjOahGHD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_x4tSoyZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVxSWYYT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MjOahGHD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_C5MBsvPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVxSWYYT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MjOahGHD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_P4tmxdYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVxSWYYT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MjOahGHD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_O0KjohsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_RVxSWYYT_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_MjOahGHD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_upDEUW33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_BTbIqFw4, 0, m, &cVar_BTbIqFw4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_p4S6cWgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_jdmA9FUl, 0, m, &cVar_jdmA9FUl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_A8VbkTCO, 0, m, &cVar_A8VbkTCO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_168S8mCl, 0, m, &cVar_168S8mCl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_PRE6QtEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jdmA9FUl, 0, m, &cVar_jdmA9FUl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CdfJq6wQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_A8VbkTCO, 0, m, &cVar_A8VbkTCO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_0ygi1N7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_168S8mCl, 0, m, &cVar_168S8mCl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_FWgIijfx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tLe9Ouqn, 0, m, &cVar_tLe9Ouqn_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_UHqiu6CZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mBFnfWKj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_j7EwrwNe_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_lT1IuJrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rb8CFy3f_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DJGNmAKE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ucbh0VjS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_f9qg56YQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YfCRPQF9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8Qoh9cft_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xICx9pXl_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_33sEnqTa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ptd7WS2z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9oeqDr1z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V14IIHo9_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_k9TyNS5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tAcYnHoE_sendMessage(_c, 0, m);
  cMsg_UYFGHQUj_sendMessage(_c, 0, m);
  cMsg_9UuUXMk5_sendMessage(_c, 0, m);
  cMsg_CHlf9OiT_sendMessage(_c, 0, m);
  cMsg_AO7JcE6h_sendMessage(_c, 0, m);
  cMsg_ANI3HLxK_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_fe8nX5oe, 0, m, &cVar_fe8nX5oe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_tLe9Ouqn, 0, m, &cVar_tLe9Ouqn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ixq7xj8e, 0, m, &cVar_ixq7xj8e_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lJsYf6rP, 0, m, &cVar_lJsYf6rP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_a4KAFqoa, 0, m, &cVar_a4KAFqoa_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yEi1Z692, 0, m, &cVar_yEi1Z692_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sx16xHFr, 0, m, &cVar_sx16xHFr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pTmMWROw, 0, m, &cVar_pTmMWROw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Tng9yCCf, 0, m, &cVar_Tng9yCCf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aixrSF8k, 0, m, &cVar_aixrSF8k_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LMLllTOr, 0, m, &cVar_LMLllTOr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dxtxzrHW, 0, m, &cVar_dxtxzrHW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cGPdl36I, 0, m, &cVar_cGPdl36I_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PQRetnKZ, 0, m, &cVar_PQRetnKZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2mY3uXHe, 0, m, &cVar_2mY3uXHe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3nVE2R10, 0, m, &cVar_3nVE2R10_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_7T5w2nk9, 0, m, &cVar_7T5w2nk9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YMeeuotE, 0, m, &cVar_YMeeuotE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_RcgX1ahg, 0, m, &cVar_RcgX1ahg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rV8QODXN, 0, m, &cVar_rV8QODXN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_q4QL9SrK, 0, m, &cVar_q4QL9SrK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eFySdU4s, 0, m, &cVar_eFySdU4s_sendMessage);
  cMsg_p4S6cWgG_sendMessage(_c, 0, m);
  cMsg_upDEUW33_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_e8mPZ16X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xzmE9vN7, HV_BINOP_MULTIPLY, 0, m, &cBinop_xzmE9vN7_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_HUt1RYK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QUXpZT2r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DoawhcMV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RmBe1NoU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_gEXhhLLH_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_CAMma95i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NcDRhYWr_sendMessage);
  cMsg_ZWG3ZnPG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_EGRTDO8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yYGDPcmj, HV_BINOP_MULTIPLY, 0, m, &cBinop_yYGDPcmj_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YE2MqUs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_5pqFuDpS_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_xBbUlcUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HU4rgvVd, HV_BINOP_MULTIPLY, 1, m, &cBinop_HU4rgvVd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2DImVkgM_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_y7EsJPsS_sendMessage);
  cMsg_lpVCckYQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_JJjxXPcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yJBfmgWO, HV_BINOP_MULTIPLY, 0, m, &cBinop_yJBfmgWO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_YOzNjm9l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_db8X8vK6_sendMessage(_c, 0, m);
  cMsg_n5MNrehs_sendMessage(_c, 0, m);
  cMsg_4nj8CnaP_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_LIGUR9fG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_2g4oLSr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_pQN1YH7L_sendMessage);
  cMsg_MR3KrgGB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_FAwz3Gku_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_a4KAFqoa, 0, m, &cVar_a4KAFqoa_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_uxTmbK4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mK9JJCeT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_W8ob96az_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_tR379nMM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FlF96X0q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pkJcfOFN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8kYGmWfg_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_jq0m9rwu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0Jkf7nCR_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rPZRJ6QH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lXaaePtF_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_uirGeezY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XRPLeorF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_35VBTYXo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wu56VW15_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_DfpEXY2n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_StxNVpFr, HV_BINOP_MULTIPLY, 0, m, &cBinop_StxNVpFr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_gh6Lgw7W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NEsQ0UOR_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oMo5D8Wr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_q84Xe37I_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_SKa5t84C_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_kyHn4l1X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_LZgW27sQ_sendMessage);
  cMsg_QYnJSciL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_T5mOEu8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6bF1RLVJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_6bF1RLVJ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_A0HwPEwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_HhbMlXkH_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_kktaTeQL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O71JH1n4, HV_BINOP_MULTIPLY, 1, m, &cBinop_O71JH1n4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_vjCalB2S_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_K9eCErwI_sendMessage);
  cMsg_1sM2qmsy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_8IlsaEAR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lVM54YI0, HV_BINOP_MULTIPLY, 0, m, &cBinop_lVM54YI0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_uDBTjqZ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2qcvY6iQ_sendMessage(_c, 0, m);
  cMsg_8AvsvqxV_sendMessage(_c, 0, m);
  cMsg_mkFoDpQS_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_17Esko6k_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_R3scQNGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_srOtpJtD_sendMessage);
  cMsg_McXLazgz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_yvilhnDy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_BTbIqFw4, 0, m, &cVar_BTbIqFw4_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_fUI44oSa, VOf(Bf0));
    __hv_varread_f(&sVarf_NTlQNedF, VOf(Bf1));
    __hv_varread_f(&sVarf_5XNC185k, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_hOV00G0m, VOf(Bf0));
    __hv_varread_f(&sVarf_0vwl8n7w, VOf(Bf1));
    __hv_varread_f(&sVarf_Ua15118s, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_c0D79il9, VOf(Bf0));
    __hv_line_f(&sLine_iJHKU8Ge, VOf(Bf1));
    __hv_line_f(&sLine_TXpf2yq6, VOf(Bf4));
    __hv_line_f(&sLine_i0ebYvao, VOf(Bf5));
    __hv_line_f(&sLine_vEq87I65, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_dCIqLV6t, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_RJHIgJ3l, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_bgJorfWO, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_heJqhLPw, VOf(Bf1));
    __hv_line_f(&sLine_SInEiuYb, VOf(Bf0));
    __hv_line_f(&sLine_CfufUUbm, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_LlPTWZNj, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_iwPjuLCM, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_9rwB7HSw, VOf(Bf7));
    __hv_line_f(&sLine_KyGvW0jx, VOf(Bf1));
    __hv_line_f(&sLine_RbdekJqV, VOf(Bf4));
    __hv_line_f(&sLine_rLKg8pux, VOf(Bf6));
    __hv_line_f(&sLine_sbhNeIwL, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_bWd3IxP3, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_fDO0pHfw, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_fUI44oSa, VIf(Bf5));
    __hv_varwrite_f(&sVarf_NTlQNedF, VIf(Bf0));
    __hv_varwrite_f(&sVarf_5XNC185k, VIf(Bf6));
    __hv_line_f(&sLine_HXyEHTNa, VOf(Bf6));
    __hv_line_f(&sLine_SUww0ejw, VOf(Bf0));
    __hv_line_f(&sLine_bbHbNLmD, VOf(Bf5));
    __hv_line_f(&sLine_ui27WL2g, VOf(Bf8));
    __hv_line_f(&sLine_bviSj19E, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_yVYZ8Gf9, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_W1UeyKoj, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_2495c0hI, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_NDMk3al6, VOf(Bf0));
    __hv_line_f(&sLine_rJmf5G3O, VOf(Bf6));
    __hv_line_f(&sLine_33mfSqbe, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_0E9n6DHc, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_RLOhNWu9, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_watCYEHl, VOf(Bf1));
    __hv_line_f(&sLine_th5WwSIZ, VOf(Bf0));
    __hv_line_f(&sLine_2aRaU7th, VOf(Bf5));
    __hv_line_f(&sLine_Ff3QFqiy, VOf(Bf4));
    __hv_line_f(&sLine_tTPO4ZQO, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_klsJqEK6, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_MBn5APwX, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_hOV00G0m, VIf(Bf8));
    __hv_varwrite_f(&sVarf_0vwl8n7w, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Ua15118s, VIf(Bf4));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
